
use mus08psidextract.dta, clear

summarize
xtsum id t lwage ed exp exp2 wks south tdum1


/* 1. Pooled OLS regression*/

regress lwage exp exp2 wks ed
estimates store POLS 


regress lwage exp exp2 wks ed, vce(cluster id)
estimates store POLSrobust

estimates table POLS POLSrobust, b(%7.4f) se(%7.4f) stats(N r2_a)

*regress lwage exp exp2 wks occ ind south smsa ms union

/*

	2. Use the residuals to get theta and estimate using FGLS
	
*/

	predict OLSresid, resid

	forvalues s=1/6 {
		qui corr OLSresid L`s'.OLSresid 
		di "Autocorrelation at lag `s' = " %6.3f r(rho)
	}
	* sigmaalpha2 = .8*sigmav2
	* sigmav2 = var(OLSresid)

	di (.884+.838+.811+.786+.75+.729)/6
	di (6*.884+5*.838+4*.811+3*.786+2*.75+.729)/21
	
	sum OLSresid, d
	gen sigmav2 = .1525969
	gen sigmaa2 = .815*sigmav2
	gen sigmau2 = sigmav2-sigmaa2
	gen theta = 1-((sigmau2)/(7*sigmaa2+sigmau2))^.5

	/*manual de-meaning */
	by id: egen meanlwage=mean(lwage)
	by id: egen meanexp=mean(exp)
	by id: egen meanexp2=mean(exp2)
	by id: egen meanwks=mean(wks)
	by id: egen meaned=mean(ed)
	
 
	gen ytilde = lwage-theta*meanlwage
	gen exptilde = exp-theta*meanexp
	gen exp2tilde = exp2-theta*meanexp2
	generate wkstilde = wks-theta*meanwks
	generate edtilde =  ed-theta*meaned
	
reg ytilde exptilde exp2tilde wkstilde edtilde
 estimates store FG
estimates table POLS POLSrobust FG, b(%7.4f) se(%7.4f) stats(N r2_a)

/*

3. Random Effects Regression

*/

xtreg lwage exp exp2 wks ed, re
estimates store RE
xttest0



/*
4.Fixed Effects Regression
*/

	/*de-meaning the data */
	xtreg lwage exp exp2 wks ed, fe
	predict alphaFE, u
	predict epsiFE, e
	predict ueFE, ue
	
	sum alphaFE, d
	
	estimates store FE
	
	/*two-step estimates to obtain the effect of education*/
		regress alphaFE ed
		
	
	gen dmlwage=lwage-meanlwage
	gen dmexp=exp-meanexp
	gen dmexp2=exp2-meanexp2
	gen dmwks=wks-meanwks
	gen dmed=ed-meaned
	
	regress dmlwage dmexp dmexp2 dmwks dmed, noconstant

/* 
 5. Dummy variable regression 
*/
	areg lwage exp exp2 wks ed, absorb(id)
	
	quietly tab id, gen(dum)
	regress lwage exp exp2 wks ed dum1-dum594


/*
6.First Differences Regression
*/
gen Dlwage=lwage-L.lwage
gen Dexp=exp-L.exp
gen Dexp2=exp2-L.exp2
gen Dwks=wks-L.wks
gen Ded=ed-L.ed

regress Dlwage Dexp Dexp2 Dwks Ded, noconstant
estimates store FD
regress D.(lwage exp exp2 wks ed), noconstant



/*
7.Between Estimation
*/

xtreg lwage exp exp2 wks ed, be
estimates store BE

regress meanlwage meanexp meanexp2 meanwks meaned


/*Compare the results*/

estimates table POLS POLSrobust RE FE FD BE FG, b stats(N) b(%7.4f) star(.05 .01 .001)

/*Fixed Effects vs Random Effects: Hausman test*/

hausman FE RE, sigmamore
xttest0


